MethodChannelCloudCardFlutter class

An implementation of CloudCardFlutterPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkDefaultApp() → Future<bool?>
override
checkDeviceSupport() → Future<bool>
override
checkRegisteredCard() → Future<CCResult>
override
deleteCard(Map<String, String> data) → Future<CCResult>
override
emptyWallet() → Future<CCResult>
override
freezeUnfreezeCard(Map<String, dynamic> data) → Future<CCResult>
override
getCard() → Future<CCResult>
override
getEmvQr(Map<String, dynamic> data) → Future<CCResult>
override
getNfcChipPosition() → Future<NfcChipPosition?>
override
getPlatformVersion() → Future<String?>
override
getSavedTransactions() → Future<CCResult>
NEW: fetches the latest saved transactions (limited to 5 on native side). Returns CCResult with data: List<Map<String, dynamic>>
override
getTokenThreshold() → Future<CCResult>
override
hideNfcChipPosition() → Future<bool>
override
initialize(Map<String, dynamic> data, CloudCardScannedCallback? onScanned, {CloudCardScannedCallback? onScanComplete}) → Future<bool>
Initializes the native SDK and sets up event callbacks. The event sent to Flutter will have keys:
override
isNfcEnabled() → Future<bool?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAppSettings() → Future<bool>
override
registerCard(Map<String, dynamic> data) → Future<CCResult>
override
replenishKeys() → Future<CCResult>
override
setActiveCard(Map<String, dynamic> data) → Future<bool>
override
setDefaultCard(Map<String, dynamic> data) → Future<bool>
override
setRequireAuth(Map<String, dynamic> data) → Future
override
showNfcChipPosition(Map<String, dynamic> data) → Future<bool>
override
toString() → String
A string representation of this object.
inherited
wipeWallet() → Future<CCResult>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited